/******************************************************************************
 * @file        MPULCD.h
 * @version     V1.00.01
 * $Revision:   0 $
 * $Date:       2017-05-11  $
 * @brief       MPULCD Driver Header File
 *
 * @note        V1.00.01 - creat.
 *
 * Copyright (C) 2017 AMICCOM Electronics Corp. All rights reserved.
 ******************************************************************************/

#ifndef __MPULCD_H__
#define __MPULCD_H__

#include "system_A3117M0.h"

/** @addtogroup A3117M0_Driver A3117M0 Driver
    @{
*/
/** @addtogroup MPULCD_Driver MPULCD Driver
    @{
*/


typedef struct
{
    uint16_t width;         // The width of LCD
    uint16_t height;        // The hight of LCD
    uint16_t xOffset;       // The offset for x-pos of Graph-RAM
    uint16_t yOffset;       // The offset for y-pos of Graph-RAM
    uint16_t interface;     // The interface of LCD: LCD_I80_16BIT, LCD_I80_8BIT, LCD_SPI
    uint8_t rgb;            // The RGB mode of LCD
    uint8_t cmdWRAM;        // The command of write Graph-RAM
    uint8_t cmdSetX;        // The command of set X-pos
    uint8_t cmdSetY;        // The command of set Y-pos
} sLCD;

extern sLCD LcdModule;
extern uint32_t DMA_RAM_Start;

#define DMA_RAM_BASE    0x20000000

#define LCD_I80_8BIT            MPULCD_CONFIG_8BITS_Msk
#define LCD_I80_16BIT           MPULCD_CONFIG_16BITS_Msk
#define LCD_SPI                 MPULCD_CONFIG_SPI_Msk

#define LCD_RGB565              0
#define LCD_RGB666_1            1
#define LCD_RGB666_2            2

#define LCD_WriteCmd(reg)       MPULCD_Write(reg, 0)        // LCD write command
#define LCD_WriteDat(dat)       MPULCD_Write(dat, 1)        // LCD write data

/**
 * @brief   Write data through MPULCD interface.
 */
extern void MPULCD_Write(uint16_t data, uint8_t a0);

/**
 * @brief   Read data through MPULCD interface.
 */
extern uint16_t MPULCD_Read(uint8_t a0);

/**
 *
 * @brief   Enable DMA and wait DMA finish
 *
 */
extern void MPULCD_EnableDMA(uint32_t offset);


/*@}*/ /* end of group MPULCD_Driver */
/*@}*/ /* end of group A3117M0_Driver */

#endif
