/**************************************************************************//**
 * @file        i2cm.h
 * @version     V1.01.00
 * $Revision:   0 $
 * $Date:       2018-04-17 $
 * @brief       I2CM Driver Header File
 *
 * @note
 *              2018-04-17  V1.01.00    Add I2CM_Setup_SA    
 * Copyright (C) 2017 AMICCOM Electronics Corp. All rights reserved.
 ******************************************************************************/

#ifndef __I2CM_H__
#define __I2CM_H__

/** @addtogroup Std_Driver Standard Driver
    @{
*/
/** @addtogroup I2CM_Driver Timer Driver
    @{
*/

/**
 * @brief   Initial I2C Master controller and set SCL clock frequency.
 */
extern void I2CM_Initial(I2CM_Type *i2cm, uint32_t tp);

/**
 * @brief   Enable the I2C Master interrupt.
 */
extern void I2CM_EnableIRQ(I2CM_Type *i2cm);

/**
 * @brief   Disable the I2C Master interrutp.
 */
extern void I2CM_DisableIRQ(I2CM_Type *i2cm);

/**
 * @brief   Setup 7bits slave address and TRX (0=RX, 1=TX)
 */
extern void I2CM_Setup(I2CM_Type *i2cm, uint8_t slave_addr, uint8_t rtx);

/**
 *
 * @brief   Setup 7bits slave address and RS bits (1=RX, 0=TX)
 *
 */
extern void I2CM_Setup_SA(I2CM_Type *i2cm, uint8_t slave_addr, uint8_t rs);

/**
 * @brief   I2C Master Transefer.
 */
extern uint32_t I2CM_Send(I2CM_Type *i2cm, uint8_t data, uint8_t mcr);

/**
 * @brief   I2C Master Receive.
 */
extern uint32_t I2CM_Read(I2CM_Type *i2cm, uint8_t *data, uint8_t mcr);


/*@}*/ /* end of group I2CM_Driver */
/*@}*/ /* end of group Std_Driver */

#endif
