/**************************************************************************//**
 * @file        PWM.c
 * @version     V1.00
 * $Revision:   0 $
 * $Date:       $
 * @brief       PWM Driver source file
 *
 * @note
 * Copyright (C) 2016 AMICCOM Electronics Corp. All rights reserved.
 *****************************************************************************/

#include "A8125M.h"

/** @addtogroup Std_Driver Standard Driver
    @{
*/
/** @addtogroup PWM_Driver Watchdog Driver
    @{
*/

/**
 *
 * @brief   Initialises the PWM.
 *
 * @param   *pwm                    PWM Pointer
 * @param   prescal                 The prescal value by power 2.
 * @param   cks                     PWM clock source select. 0=system clock, 1=RTC/IRC
 * @param   enable                  PWM enable
 * @param   low                     PWM LOW width by 256-low
 * @param   high                    PWM HIGH width by 256-high
 * @return  none
 */
void PWM_Initial(PWM_Type *pwm, uint32_t prescal, uint32_t cks, uint32_t enable, uint32_t low, uint32_t high)
{
    pwm->DUTY = ((low&0xFF)<<PWM_HIGH_LOW_LOW_Pos) | ((high&0xFF)<<PWM_HIGH_LOW_HIGH_Pos);
    pwm->CTRL = ((prescal&0x07)<<PWM_CTRL_PRESCAL_Pos);
    pwm->CTRL |= (cks)?(PWM_CTRL_CKS_Msk):(0);
    pwm->CTRL |= (enable)?(PWM_CTRL_EN_Msk):(0);
}

/**
 *
 * @brief   Enable PWM
 *
 * @param   *pwm                    PWM Pointer
 * @return  none
 */
void PWM_Enable(PWM_Type *pwm)
{
    pwm->CTRL |= PWM_CTRL_EN_Msk;
}

/**
 *
 * @brief   Disable PWM
 *
 * @param   *pwm                    PWM Pointer
 * @return  none
 */
void PWM_Disable(PWM_Type *pwm)
{
    pwm->CTRL &= ~PWM_CTRL_EN_Msk;
}



/*@}*/ /* end of group PWM_Driver */
/*@}*/ /* end of group Std_Driver */
